@@ -17,7 +17,7 @@
  */
 #ifndef _GIAC_GEN_H
 #define _GIAC_GEN_H
-#ifdef KHICAS
+#if defined KHICAS || defined SDL_KHICAS
 extern size_t stackptr;
 #endif
 
@@ -441,7 +441,11 @@ namespace giac {
   public:
     bool operator () (const gen & a,const gen & b) const;
   };
+#if 0 //def CPP11 // otherwise crash on A[1,1]:=1; A[1,2]:=2;
+  typedef std::map<gen,gen,std::function<bool(const gen &, const gen &)> > gen_map;
+#else
   typedef std::map<gen,gen,comparegen> gen_map;
+#endif
 #else
   typedef std::map<gen,gen,const std::pointer_to_binary_function < const gen &, const gen &, bool> > gen_map;
 #endif
@@ -901,8 +905,12 @@ namespace giac {
     gen_map m;
 #if 1 // def NSPIRE
     ref_gen_map(): ref_count(1),m() {}
+#else
+#ifdef CPP11
+     ref_gen_map(const std::function<bool(const gen &, const gen &)> & p): ref_count(1),m(p) {}
 #else
     ref_gen_map(const std::pointer_to_binary_function < const gen &, const gen &, bool> & p): ref_count(1),m(p) {}
+#endif // CPP11
 #endif
     ref_gen_map(const gen_map & M):ref_count(1),m(M) {}
   };
@@ -910,7 +918,7 @@ namespace giac {
   struct alias_ref_fraction { ref_count_t ref_count; alias_gen num; alias_gen den; };
   struct alias_ref_complex {
     ref_count_t ref_count;
-#ifdef BIGENDIAN
+#if defined BIGENDIAN //&& !defined __VISUALC__
     alias_gen im,re;
     int display;
 #else
@@ -1001,6 +1009,7 @@ namespace giac {
 
 
   bool is_zero(const gen & a,GIAC_CONTEXT0);
+  bool is_zero_or_contains(const gen & g,GIAC_CONTEXT); // for intervals
   bool is_exactly_zero(const gen & a);
   bool is_one(const gen & a);
   inline bool is_exactly_one(const gen & a){ return is_one(a); }
@@ -1312,7 +1321,7 @@ namespace giac {
   std::string print_the_type(int val,GIAC_CONTEXT);
 
   // I/O
-#ifdef KHICAS
+#if defined KHICAS || defined SDL_KHICAS
   stdostream & operator << (stdostream & os,const gen & a);
 #endif
 #ifdef NSPIRE
@@ -1414,7 +1423,7 @@ namespace giac {
   // Terminal data for EQW display
   struct eqwdata {
     gen g; 
-#if defined KHICAS || defined FXCG
+#if defined KHICAS || defined SDL_KHICAS || defined FXCG
     short int x,y,dx,dy;
     short int baseline;
 #else
@@ -1444,7 +1453,7 @@ namespace giac {
 
   class identificateur {
   public:
-    int * ref_count;
+    int * ref_count_ptr;
     gen * value;
     // std::string * name;
     const char * id_name;
